# FaSTGLETree

Simple christmas tree from 2 PCBs with pseudo-random blinkenlights. Soldering workshop subject.

![3D CAD rendering of an electronics-based christmas tree made from 2 PCBs slotted into each other to give it 3-dimensionality. There's a 3D printed star on top.](render.png)

# Features / Function

- CR2023 coin cell for power
- 1-pos SMD dip switch for on/off
- button for manual shifting
- 3 pin header with jumper for switching between timer and button for shifting
- All ICs are low voltage (down to 2V / 2.5V) variants
  - 555 Timer set at ~.5Hz
  - SIPO 8 bit shift register for patterns
  - Pattern scrambling with 2x4 NAND gates
  - Feedback from 2 NANDs into shift register
- 16 SMD LEDs connected to shift register and NAND outputs
- 1 yellow THT LED always-on on top
  - Transparently 3D-printable star cap

# Learn how to solder SMD:

[See Slides (in German)](docs/FaSTGLET-Part4-Lötworkshop.pdf)

# PCB Manufacturing

I usually order from JLC with the cheapest options, make sure to choose the manual placement of the order number (marker already included in Silkscreen)

# Build instructions

Assembly Guides: [Board A](https://fasttube.de/bestueckung/FaSTGLETree/A.html), [Board B](https://fasttube.de/bestueckung/FaSTGLETree/B.html)

- It's recommended to make sure each PCB is in the best state it can be in and has no short circuits before combining them. Afterwards, soldering becomes more difficult.
- For SMD parts, always solder a single pad/pin first before continuing to others
- Paz attention to the Pin-1-Marker! On ICs, it's usually a dot, circle or line. On the PCB, it's either an elongated line or a triangle.
- Pin 1 markings are the elongated silkscreen line and the dot/line on the IC
- LED directions are not marked. The LED arrow should always point to the tree trunk/inwards (Anode to tip of branch)
- The kit usually includes 3 or 4 different colors of LEDs. It's recommended to try and spread all colors across each visible surface.
- There's no pattern to whether the LED or Resistor is on top on the LED branches. Always check the assembly guide!
- J9 is usually not populated, it's left for external power
- The THT LED atop should have its leads shortened to ~7-10mm
- The THT LED atop is oriented using the flat side of its rim. The Flat side goes to the straight line, the round side to the rounded line
- Insert the coin cell with the + facing away from the tree's stem.
- Keep in mind the Errata section below

## How to tell the components in the kit apart

Since they're not labeled, you have to go off of a few clues:

- Generally, the number of parts is the best clue. You usually have the exact amount or one more.
- Capacitors (C) have a brown body with no letters. They come on white strips
- Resistors (R) have a white bottom and black top, with white digits/letters explaining their value. They come on white strips.
    - `471` means `47` with `1` 0, so 470 ohms
    - `01C` means 10Kohms with 1% tolerance, no idea why
- LEDs (D) have clear tops and come on black strips. The diode direction is indicated by the trangle on their bottom side.
    - 0603 LEDs are very hard to solder. Don't fret if they don't work first-try
- The big ICs are labeled with a number similar to their model number
- The rest should be guessable from the part's footprint

# Errata

- [2022 version] There is a pull-up resistor missing for the button. A 10kOhm THT resistor can be soldered from the backside of the bin header to the battery holder.
- [2022 and 2023 version] Be careful to not scratch the pcb surfaces with the legs of the top LED in order not to create a short circuit
- [2024 version] There is a missing connection betreen R5 Pin 1 and +BATT. A bodge wire from R5 (outside) to the battery holder solder point is recommended. Otherwise, the push button functionality most likely does not work.

# Cost

~10€ BOM @ 30pcs

# Licensing

Licensed under CERN OHL, see LICENSE.txt
